##
## .clircrc.py for Teemu Kalvas <chery@s2.org>
##

import regex
import string
from types import *
from user import User

verbose = 1 # give verbose error messages
motd = 0 # do not print the server motd

# the extensive way to specify connections
want_servers = [(
    'irc-2.cs.hut.fi', 6667, # server, port
    ['cliini', 'oerliini', 'seeliini', 'cli', 'ilciin'], # list of nicks
    ['#cokers', '#polonhoitoalue', '#modeemi', '#tampere']), # list of channels
                (
    'hinaja.noitatieto.fi', 6667, # a second server
    ['cliini', 'cli'],
    ['#a'])]

# you could also instead of want_servers just specify
# nick = 'nick'
# server = 'server.address'
# port = port_number

# default encryption/decryption keys for addresses (regex/key -pairs)
default_key = [('.*', 'kala')]

def handle_cmd_find(user, p, tail):
    win = p.screen.current
    llist = win.lines
    i = win.at[0] - 1
    while i:
        str = llist.lookup(i)
        if str == ():
            break
        if string.find(str, tail) <> -1:
            break
        i = i - 1
    while win.at[0] >= i:
        win.page_up()
    win.page_down()

handle_ctrl_underscore = User.handle_keycmd_prev_window
# ^_ moves to previous window
handle_ctrl_backslash = User.handle_keycmd_next_window
# ^\ moves to next window

# This is my rather bizarre regular expression -based auto-op system.
def _gen(obj):
    t = type(obj)
    if t == StringType:
	return obj
    elif t == ListType:
	go = map(_gen, obj)
	return '\(' + reduce(lambda x, y: x + '\|' + y, go[1:], go[0]) + '\)'
    elif t == TupleType:
	go = map(_gen, obj)
	return reduce(lambda x, y: x + y, go[1:], go[0])
    else:
	return ''

def gen(obj):
    return regex.compile(_gen(obj))

ops = {}
ops_all = gen(['.*@tjtk2\.trin\.cam\.ac\.uk',
               'chery@o68c\.erkki\.ton\.tut\.fi',
               ('sandra@', ['simpukka', 'kotilo'], '\.saunalahti\.fi'),
               ('.?sandra@', ['hilavitkutin\.pp\.', 'smtp',
                              'borg\.', ''],
                'sci\.fi')])
ops['#cokers'] = \
    gen([('.*@', [(['.*\.', ''], 'vvf'),
                  (['o68b\.erkki', 'a29c\.otanner', 'f298b\.w3',
                    (['a31b', 'a48b'], '\.mtalo'),
                    (['g156b', 'h167', 'd67'], '\.lanhovi')],
                   '\.ton\.tut')], '\.fi'),
         ([([(['pekangas', 'hali', 'sly', 'sunnu'], '@',
              ['assari', 'lehtori'], '\.cc'),
             (['k153997', 'sunnu', 'c142092'], '.*\.cs')],
            '\.tut'),
           ('jansu@borg\.sci'), '\.fi'])])
ops['#noitatieto'] = gen('.*@.*\.noitatieto\.fi')


def autoop(addr, chan):
    return ops_all.match(addr) > 0 or \
	   (ops.has_key(chan) and ops[chan].match(addr) > 0)

# adds a command /isop
def handle_cmd_isop(user, p, tail):
    if autoop(tail, p.screen.current.name):
        p.screen.current.log('*** ' + tail + ' is auto-opped')
    else:
        p.screen.current.log('*** ' + tail + ' is not auto-opped')

# adds some keyboard shortcuts (the function keys seem to be broken now)
def handle_key_f9(user, p):
    for c in 'http://www.s2.org/~chery/':
	p.screen.edit_field.insert(ord(c))

def handle_key_f10(user, p):
    for c in 'http://www.s2.org/polonhoitoalue/':
	p.screen.edit_field.insert(ord(c))

## End. ##
